@@ -2,9 +2,6 @@ from datetime import datetime
 from requests import get
 from typing import List, Union
 from xmltodict import parse as xmlparse
-from pyrmv.classes.Trip import Trip
-
-from pyrmv.utility.find_exception import find_exception
 
 try:
     from typing import Literal
@@ -127,14 +124,14 @@ def trip_find(accessId: str,
     ) -> dict:
     """The trip service calculates a trip from a specified origin to a specified destination. These might be
     stop/station IDs or coordinates based on addresses and points of interest validated by the location service or
-    coordinates freely defined by the client.
+    coordinates freely defined by the client.  
 
     Read more about this in section 2.12. "Trip Search (trip)" of HAFAS ReST Documentation.  
 
     ### Args:
         * accessId (str): Access ID for identifying the requesting client. Get your key on [RMV website](https://opendata.rmv.de/site/start.html).
         * lang (Literal["de","da","en","es","fr","hu","it","nl","no","pl","sv","tr"], optional): The language of response. Defaults to "en".
-        * json (bool, optional): Whether response should be retrieved as JSON. XML is returned if False. Only matters if raw_response is True. Defaults to True.
+        * json (bool, optional): Whether response should be retrieved as JSON. XML is returned if False. Defaults to True.
         * originId (str, optional): Specifies the station/stop ID of the origin for the trip. Such ID can be retrieved from stopByName() or stopByCoords(). Defaults to None.
         * originExtId (str, optional): Deprecated. Please use originId as it supports external IDs. Specifies the external station/stop ID of the origin for the trip. Such ID can be retrieved from stopByName() or stopByCoords(). Defaults to None.
         * originCoordLat (Union[str, float], optional): Latitude of station/stop coordinate of the trip's origin. The coordinate can be retrieved from stopByName() or stopByCoords(). Defaults to None.
@@ -156,8 +153,8 @@ def trip_find(accessId: str,
         * maxChangeTime (int, optional): Maximum change time at stop in minutes. Defaults to None.
         * addChangeTime (int, optional): This amount of minutes is added to the change time at each stop. Defaults to None.
         * maxChange (int, optional): Maximum number of changes. In range 0-11. Defaults to None.
-        * date (str, optional): Sets the start date for which the departures shall be retrieved. Represented in the format `YYYY-MM-DD`. By default the current server date is used. Defaults to None.
-        * time (str, optional): Sets the start time for which the departures shall be retrieved. Represented in the format `hh:mm[:ss]` in 24h nomenclature. Seconds will be ignored for requests. By default the current server time is used. Defaults to None.
+        * date (Union[str, datetime], optional): Sets the start date for which the departures shall be retrieved. Represented in the format `YYYY-MM-DD`. By default the current server date is used. Defaults to None.
+        * time (Union[str, datetime], optional): Sets the start time for which the departures shall be retrieved. Represented in the format `hh:mm[:ss]` in 24h nomenclature. Seconds will be ignored for requests. By default the current server time is used. Defaults to None.
         * searchForArrival (bool, optional): If set, the date and time parameters specify the arrival time for the trip search instead of the departure time. Defaults to False.
         * numF (int, optional): Minimum number of trips after the search time. Sum of numF and numB has to be less or equal 6. Read more about this in HAFAS ReST Documentation. In range 1-6. Defaults to None.
         * numB (int, optional): Minimum number of trips before the search time. Sum of numF and numB has to be less or equal 6. Read more about this in HAFAS ReST Documentation. In range 0-6. Defaults to None.
@@ -242,13 +239,15 @@ def trip_find(accessId: str,
                     payload[str(var)] = val.strftime("%H:%M")
                 else:
                     payload[str(var)] = val
-        elif str(var) not in ["json", "headers", "payload", "raw_response"]:
+        elif str(var) not in ["json", "headers", "payload"]:
             if val != None:
                 payload[str(var)] = val
 
     output = get("https://www.rmv.de/hapi/trip", params=payload, headers=headers)
 
-    find_exception(output.json())
+    # Exceptions checker moved to normal methods
+    # and exceptions will no longer raise in raw ones.
+    # find_exception(output.json())
 
     if json:
         return output.json()
